@@ -7,10 +7,11 @@
 */
 
 #include "katetextbuffertest.h"
-#include "katetextbuffer.h"
-#include "katetextcursor.h"
+#include "katebuffer.h"
+#include "katedocument.h"
 #include "katetextfolding.h"
 #include <kateglobal.h>
+#include <ktexteditor/movingcursor.h>
 
 QTEST_MAIN(KateTextBufferTest)
 
@@ -27,7 +28,8 @@ KateTextBufferTest::~KateTextBufferTest()
 void KateTextBufferTest::basicBufferTest()
 {
     // construct an empty text buffer
-    Kate::TextBuffer buffer(nullptr, 1);
+    KTextEditor::DocumentPrivate doc;
+    Kate::TextBuffer &buffer = doc.buffer();
 
     // one line per default
     QVERIFY(buffer.lines() == 1);
@@ -44,13 +46,14 @@ void KateTextBufferTest::basicBufferTest()
 void KateTextBufferTest::wrapLineTest()
 {
     // construct an empty text buffer
-    Kate::TextBuffer buffer(nullptr, 1);
+    KTextEditor::DocumentPrivate doc;
+    Kate::TextBuffer &buffer = doc.buffer();
 
     // wrap first empty line -> we should have two empty lines
     buffer.startEditing();
     buffer.wrapLine(KTextEditor::Cursor(0, 0));
     buffer.finishEditing();
-    buffer.debugPrint(QLatin1String("Two empty lines"));
+    buffer.debugPrint(QStringLiteral("Two empty lines"));
     QVERIFY(buffer.text() == QLatin1String("\n"));
 
     // unwrap again -> only one empty line
@@ -59,20 +62,21 @@ void KateTextBufferTest::wrapLineTest()
     buffer.finishEditing();
 
     // print debug
-    buffer.debugPrint(QLatin1String("Empty Buffer"));
+    buffer.debugPrint(QStringLiteral("Empty Buffer"));
     QVERIFY(buffer.text() == QString());
 }
 
 void KateTextBufferTest::insertRemoveTextTest()
 {
     // construct an empty text buffer
-    Kate::TextBuffer buffer(nullptr, 1);
+    KTextEditor::DocumentPrivate doc;
+    Kate::TextBuffer &buffer = doc.buffer();
 
     // wrap first line
     buffer.startEditing();
     buffer.wrapLine(KTextEditor::Cursor(0, 0));
     buffer.finishEditing();
-    buffer.debugPrint(QLatin1String("Two empty lines"));
+    buffer.debugPrint(QStringLiteral("Two empty lines"));
     QVERIFY(buffer.text() == QLatin1String("\n"));
 
     // remember second line
@@ -82,7 +86,7 @@ void KateTextBufferTest::insertRemoveTextTest()
     buffer.startEditing();
     buffer.unwrapLine(1);
     buffer.finishEditing();
-    buffer.debugPrint(QLatin1String("One empty line"));
+    buffer.debugPrint(QStringLiteral("One empty line"));
     QVERIFY(buffer.text() == QString());
 
     // second text line should be still there
@@ -91,30 +95,30 @@ void KateTextBufferTest::insertRemoveTextTest()
 
     // insert text
     buffer.startEditing();
-    buffer.insertText(KTextEditor::Cursor(0, 0), QLatin1String("testremovetext"));
+    buffer.insertText(KTextEditor::Cursor(0, 0), QStringLiteral("testremovetext"));
     buffer.finishEditing();
-    buffer.debugPrint(QLatin1String("One line"));
+    buffer.debugPrint(QStringLiteral("One line"));
     QVERIFY(buffer.text() == QLatin1String("testremovetext"));
 
     // remove text
     buffer.startEditing();
     buffer.removeText(KTextEditor::Range(KTextEditor::Cursor(0, 4), KTextEditor::Cursor(0, 10)));
     buffer.finishEditing();
-    buffer.debugPrint(QLatin1String("One line"));
+    buffer.debugPrint(QStringLiteral("One line"));
     QVERIFY(buffer.text() == QLatin1String("testtext"));
 
     // wrap text
     buffer.startEditing();
     buffer.wrapLine(KTextEditor::Cursor(0, 2));
     buffer.finishEditing();
-    buffer.debugPrint(QLatin1String("Two line"));
+    buffer.debugPrint(QStringLiteral("Two line"));
     QVERIFY(buffer.text() == QLatin1String("te\nsttext"));
 
     // unwrap text
     buffer.startEditing();
     buffer.unwrapLine(1);
     buffer.finishEditing();
-    buffer.debugPrint(QLatin1String("One line"));
+    buffer.debugPrint(QStringLiteral("One line"));
     QVERIFY(buffer.text() == QLatin1String("testtext"));
 }
 
@@ -123,90 +127,77 @@ void KateTextBufferTest::cursorTest()
     // last buffer content, for consistence checks
     QString lastBufferContent;
 
-    // test with different block sizes
-    for (int i = 1; i <= 4; ++i) {
-        // construct an empty text buffer
-        Kate::TextBuffer buffer(nullptr, i);
+    // construct an empty text buffer
+    KTextEditor::DocumentPrivate doc;
+    Kate::TextBuffer &buffer = doc.buffer();
 
-        // wrap first line
-        buffer.startEditing();
-        buffer.insertText(KTextEditor::Cursor(0, 0), QLatin1String("sfdfjdsklfjlsdfjlsdkfjskldfjklsdfjklsdjkfl"));
-        buffer.wrapLine(KTextEditor::Cursor(0, 8));
-        buffer.wrapLine(KTextEditor::Cursor(1, 8));
-        buffer.wrapLine(KTextEditor::Cursor(2, 8));
-        buffer.finishEditing();
-        buffer.debugPrint(QLatin1String("Cursor buffer"));
+    // wrap first line
+    buffer.startEditing();
+    buffer.insertText(KTextEditor::Cursor(0, 0), QStringLiteral("sfdfjdsklfjlsdfjlsdkfjskldfjklsdfjklsdjkfl"));
+    buffer.wrapLine(KTextEditor::Cursor(0, 8));
+    buffer.wrapLine(KTextEditor::Cursor(1, 8));
+    buffer.wrapLine(KTextEditor::Cursor(2, 8));
+    buffer.finishEditing();
+    buffer.debugPrint(QStringLiteral("Cursor buffer"));
 
-        // construct cursor
-        Kate::TextCursor *cursor1 = new Kate::TextCursor(buffer, KTextEditor::Cursor(0, 0), Kate::TextCursor::MoveOnInsert);
-        QVERIFY(cursor1->toCursor() == KTextEditor::Cursor(0, 0));
-        // printf ("cursor %d, %d\n", cursor1->line(), cursor1->column());
+    // construct cursor
+    KTextEditor::MovingCursor *cursor1 = doc.newMovingCursor(KTextEditor::Cursor(0, 0), KTextEditor::MovingCursor::MoveOnInsert);
+    QVERIFY(cursor1->toCursor() == KTextEditor::Cursor(0, 0));
+    // printf ("cursor %d, %d\n", cursor1->line(), cursor1->column());
 
-        // Kate::TextCursor *cursor2 = new Kate::TextCursor (buffer, KTextEditor::Cursor (1, 8), Kate::TextCursor::MoveOnInsert);
-        // printf ("cursor %d, %d\n", cursor2->line(), cursor2->column());
+    // insert text
+    buffer.startEditing();
+    buffer.insertText(KTextEditor::Cursor(0, 0), QStringLiteral("hallo"));
+    buffer.finishEditing();
+    buffer.debugPrint(QStringLiteral("Cursor buffer"));
 
-        // Kate::TextCursor *cursor3 = new Kate::TextCursor (buffer, KTextEditor::Cursor (0, 123), Kate::TextCursor::MoveOnInsert);
-        // printf ("cursor %d, %d\n", cursor3->line(), cursor3->column());
+    // printf ("cursor %d, %d\n", cursor1->line(), cursor1->column());
+    QVERIFY(cursor1->toCursor() == KTextEditor::Cursor(0, 5));
 
-        // Kate::TextCursor *cursor4 = new Kate::TextCursor (buffer, KTextEditor::Cursor (1323, 1), Kate::TextCursor::MoveOnInsert);
-        // printf ("cursor %d, %d\n", cursor4->line(), cursor4->column());
+    // remove text
+    buffer.startEditing();
+    buffer.removeText(KTextEditor::Range(KTextEditor::Cursor(0, 4), KTextEditor::Cursor(0, 10)));
+    buffer.finishEditing();
+    buffer.debugPrint(QStringLiteral("Cursor buffer"));
 
-        // insert text
-        buffer.startEditing();
-        buffer.insertText(KTextEditor::Cursor(0, 0), QLatin1String("hallo"));
-        buffer.finishEditing();
-        buffer.debugPrint(QLatin1String("Cursor buffer"));
+    // printf ("cursor %d, %d\n", cursor1->line(), cursor1->column());
+    QVERIFY(cursor1->toCursor() == KTextEditor::Cursor(0, 4));
 
-        // printf ("cursor %d, %d\n", cursor1->line(), cursor1->column());
-        QVERIFY(cursor1->toCursor() == KTextEditor::Cursor(0, 5));
+    // wrap line
+    buffer.startEditing();
+    buffer.wrapLine(KTextEditor::Cursor(0, 3));
+    buffer.finishEditing();
+    buffer.debugPrint(QStringLiteral("Cursor buffer"));
 
-        // remove text
-        buffer.startEditing();
-        buffer.removeText(KTextEditor::Range(KTextEditor::Cursor(0, 4), KTextEditor::Cursor(0, 10)));
-        buffer.finishEditing();
-        buffer.debugPrint(QLatin1String("Cursor buffer"));
+    // printf ("cursor %d, %d\n", cursor1->line(), cursor1->column());
+    QVERIFY(cursor1->toCursor() == KTextEditor::Cursor(1, 1));
 
-        // printf ("cursor %d, %d\n", cursor1->line(), cursor1->column());
-        QVERIFY(cursor1->toCursor() == KTextEditor::Cursor(0, 4));
+    // unwrap line
+    buffer.startEditing();
+    buffer.unwrapLine(1);
+    buffer.finishEditing();
+    buffer.debugPrint(QStringLiteral("Cursor buffer"));
 
-        // wrap line
-        buffer.startEditing();
-        buffer.wrapLine(KTextEditor::Cursor(0, 3));
-        buffer.finishEditing();
-        buffer.debugPrint(QLatin1String("Cursor buffer"));
+    // printf ("cursor %d, %d\n", cursor1->line(), cursor1->column());
+    QVERIFY(cursor1->toCursor() == KTextEditor::Cursor(0, 4));
 
-        // printf ("cursor %d, %d\n", cursor1->line(), cursor1->column());
-        QVERIFY(cursor1->toCursor() == KTextEditor::Cursor(1, 1));
-
-        // unwrap line
-        buffer.startEditing();
-        buffer.unwrapLine(1);
-        buffer.finishEditing();
-        buffer.debugPrint(QLatin1String("Cursor buffer"));
-
-        // printf ("cursor %d, %d\n", cursor1->line(), cursor1->column());
-        QVERIFY(cursor1->toCursor() == KTextEditor::Cursor(0, 4));
-
-        // verify content
-        if (i > 1) {
-            QVERIFY(lastBufferContent == buffer.text());
-        }
-
-        // remember content
-        lastBufferContent = buffer.text();
-    }
+    // remember content
+    lastBufferContent = buffer.text();
+    // verify content
+    QVERIFY(lastBufferContent == buffer.text());
 }
 
 void KateTextBufferTest::foldingTest()
 {
     // construct an empty text buffer & folding info
-    Kate::TextBuffer buffer(nullptr, 1);
+    KTextEditor::DocumentPrivate doc;
+    KateBuffer &buffer = doc.buffer();
     Kate::TextFolding folding(buffer);
 
     // insert some text
     buffer.startEditing();
     for (int i = 0; i < 100; ++i) {
-        buffer.insertText(KTextEditor::Cursor(i, 0), QLatin1String("1234567890"));
+        buffer.insertText(KTextEditor::Cursor(i, 0), QStringLiteral("1234567890"));
         if (i < 99) {
             buffer.wrapLine(KTextEditor::Cursor(i, 10));
         }
@@ -215,7 +206,7 @@ void KateTextBufferTest::foldingTest()
     QVERIFY(buffer.lines() == 100);
 
     // starting with empty folding!
-    folding.debugPrint(QLatin1String("Empty Folding"));
+    folding.debugPrint(QStringLiteral("Empty Folding"));
     QVERIFY(folding.debugDump() == QLatin1String("tree  - folded "));
 
     // check visibility
@@ -229,13 +220,13 @@ void KateTextBufferTest::foldingTest()
     QVERIFY(folding.newFoldingRange(KTextEditor::Range(KTextEditor::Cursor(5, 0), KTextEditor::Cursor(10, 0))) == 0);
 
     // we shall have now exactly one range toplevel, that is not folded!
-    folding.debugPrint(QLatin1String("One Toplevel Fold"));
+    folding.debugPrint(QStringLiteral("One Toplevel Fold"));
     QVERIFY(folding.debugDump() == QLatin1String("tree [5:0  10:0] - folded "));
 
     // fold the range!
     QVERIFY(folding.foldRange(0));
 
-    folding.debugPrint(QLatin1String("One Toplevel Fold - Folded"));
+    folding.debugPrint(QStringLiteral("One Toplevel Fold - Folded"));
     QVERIFY(folding.debugDump() == QLatin1String("tree [5:0 f 10:0] - folded [5:0 f 10:0]"));
 
     // check visibility
@@ -255,7 +246,7 @@ void KateTextBufferTest::foldingTest()
     }
 
     // there shall be one range starting at 5
-    QVector<QPair<qint64, Kate::TextFolding::FoldingRangeFlags>> forLine = folding.foldingRangesStartingOnLine(5);
+    QList<QPair<qint64, Kate::TextFolding::FoldingRangeFlags>> forLine = folding.foldingRangesStartingOnLine(5);
     QVERIFY(forLine.size() == 1);
     QVERIFY(forLine[0].first == 0);
     QVERIFY(forLine[0].second & Kate::TextFolding::Folded);
@@ -264,7 +255,7 @@ void KateTextBufferTest::foldingTest()
     QVERIFY(folding.newFoldingRange(KTextEditor::Range(KTextEditor::Cursor(20, 0), KTextEditor::Cursor(30, 0)), Kate::TextFolding::Folded) == 1);
 
     // we shall have now exactly two range toplevel
-    folding.debugPrint(QLatin1String("Two Toplevel Folds"));
+    folding.debugPrint(QStringLiteral("Two Toplevel Folds"));
     QVERIFY(folding.debugDump() == QLatin1String("tree [5:0 f 10:0] [20:0 f 30:0] - folded [5:0 f 10:0] [20:0 f 30:0]"));
 
     // check visibility
@@ -314,7 +305,7 @@ void KateTextBufferTest::foldingTest()
     QVERIFY(folding.newFoldingRange(KTextEditor::Range(KTextEditor::Cursor(15, 0), KTextEditor::Cursor(25, 0)), Kate::TextFolding::Folded) == -1);
 
     // we shall still have now exactly two range toplevel
-    folding.debugPrint(QLatin1String("Still Two Toplevel Folds"));
+    folding.debugPrint(QStringLiteral("Still Two Toplevel Folds"));
     QVERIFY(folding.debugDump() == QLatin1String("tree [5:0 f 10:0] [20:0 f 30:0] - folded [5:0 f 10:0] [20:0 f 30:0]"));
 
     // still 15 lines are hidden
@@ -324,7 +315,7 @@ void KateTextBufferTest::foldingTest()
     QVERIFY(folding.newFoldingRange(KTextEditor::Range(KTextEditor::Cursor(15, 0), KTextEditor::Cursor(35, 0)), Kate::TextFolding::Folded) == 2);
 
     // we shall have now exactly two range toplevel and one embedded fold
-    folding.debugPrint(QLatin1String("Two Toplevel Folds, One Nested Fold"));
+    folding.debugPrint(QStringLiteral("Two Toplevel Folds, One Nested Fold"));
     QVERIFY(folding.debugDump() == QLatin1String("tree [5:0 f 10:0] [15:0 f [20:0 f 30:0] 35:0] - folded [5:0 f 10:0] [15:0 f 35:0]"));
 
     // 25 lines are hidden
@@ -349,7 +340,7 @@ void KateTextBufferTest::foldingTest()
     QVERIFY(folding.newFoldingRange(KTextEditor::Range(KTextEditor::Cursor(0, 0), KTextEditor::Cursor(50, 0)), Kate::TextFolding::Folded) == 3);
 
     // we shall have now exactly one range toplevel and many embedded fold
-    folding.debugPrint(QLatin1String("One Toplevel + Embedded Folds"));
+    folding.debugPrint(QStringLiteral("One Toplevel + Embedded Folds"));
     QVERIFY(folding.debugDump() == QLatin1String("tree [0:0 f [5:0 f 10:0] [15:0 f [20:0 f 30:0] 35:0] 50:0] - folded [0:0 f 50:0]"));
 
     // there shall still be one range starting at 20
@@ -361,7 +352,7 @@ void KateTextBufferTest::foldingTest()
     // add more regions starting at 20
     QVERIFY(folding.newFoldingRange(KTextEditor::Range(KTextEditor::Cursor(20, 5), KTextEditor::Cursor(24, 0)), Kate::TextFolding::Folded) == 4);
     QVERIFY(folding.newFoldingRange(KTextEditor::Range(KTextEditor::Cursor(20, 3), KTextEditor::Cursor(25, 0)), Kate::TextFolding::Folded) == 5);
-    folding.debugPrint(QLatin1String("More ranges at 20"));
+    folding.debugPrint(QStringLiteral("More ranges at 20"));
 
     // there shall still be three ranges starting at 20
     forLine = folding.foldingRangesStartingOnLine(20);
@@ -386,13 +377,14 @@ void KateTextBufferTest::foldingTest()
 
     // restore state
     folding.importFoldingRanges(folds);
-    QVERIFY(folding.debugDump() == textDump);
+    QCOMPARE(folding.debugDump(), textDump);
 }
 
 void KateTextBufferTest::nestedFoldingTest()
 {
     // construct an empty text buffer & folding info
-    Kate::TextBuffer buffer(nullptr, 1);
+    KTextEditor::DocumentPrivate doc;
+    Kate::TextBuffer &buffer = doc.buffer();
     Kate::TextFolding folding(buffer);
 
     // insert two nested folds in 5 lines
@@ -431,18 +423,18 @@ void KateTextBufferTest::saveFileInUnwritableFolder()
 
     QFile::setPermissions(folder_name, QFile::ExeOwner);
 
-    Kate::TextBuffer buffer(nullptr, 1);
-    buffer.setTextCodec(QTextCodec::codecForName("UTF-8"));
-    buffer.setFallbackTextCodec(QTextCodec::codecForName("UTF-8"));
+    KTextEditor::DocumentPrivate doc;
+    Kate::TextBuffer &buffer = doc.buffer();
+    buffer.setTextCodec(QStringLiteral("UTF-8"));
+    buffer.setFallbackTextCodec(QStringLiteral("UTF-8"));
     bool a;
     bool b;
     int c;
     buffer.load(file_path, a, b, c, true);
     buffer.clear();
     buffer.startEditing();
-    buffer.insertText(KTextEditor::Cursor(0, 0), QLatin1String("ABC"));
+    buffer.insertText(KTextEditor::Cursor(0, 0), QStringLiteral("ABC"));
     buffer.finishEditing();
-    qDebug() << buffer.text();
     buffer.save(file_path);
 
     f.open(QIODevice::ReadOnly);
@@ -468,16 +460,17 @@ void KateTextBufferTest::saveFileWithElevatedPrivileges()
     QVERIFY(f.flush());
     f.close();
 
-    Kate::TextBuffer buffer(nullptr, 1, true);
-    buffer.setTextCodec(QTextCodec::codecForName("UTF-8"));
-    buffer.setFallbackTextCodec(QTextCodec::codecForName("UTF-8"));
+    KTextEditor::DocumentPrivate doc;
+    Kate::TextBuffer buffer(&doc, true);
+    buffer.setTextCodec(QStringLiteral("UTF-8"));
+    buffer.setFallbackTextCodec(QStringLiteral("UTF-8"));
     bool a;
     bool b;
     int c;
     buffer.load(file_path, a, b, c, true);
     buffer.clear();
     buffer.startEditing();
-    buffer.insertText(KTextEditor::Cursor(0, 0), QLatin1String("ABC"));
+    buffer.insertText(KTextEditor::Cursor(0, 0), QStringLiteral("ABC"));
     buffer.finishEditing();
     qDebug() << buffer.text();
     buffer.save(file_path);
