@@ -11,7 +11,7 @@
 #include <QObject>
 #include <QString>
 
-#include <KAuth>
+#include <KAuth/ActionReply>
 
 using namespace KAuth;
 
@@ -26,17 +26,7 @@ using namespace KAuth;
  */
 class SecureTextBuffer : public QObject
 {
-    Q_OBJECT
-
 public:
-    SecureTextBuffer()
-    {
-    }
-
-    ~SecureTextBuffer()
-    {
-    }
-
     /**
      * Common helper method
      */
@@ -52,7 +42,7 @@ private:
 
     static bool moveFile(const QString &sourceFile, const QString &targetFile);
 
-public Q_SLOTS:
+public:
     /**
      * KAuth action to perform both prepare or move work based on given parameters.
      * We keep this code in one method to prevent multiple KAuth user queries during one save action.
