@@ -1,49 +1,53 @@
-/* This file is part of the KDE libraries
-   Copyright (C) 2001 Christoph Cullmann <cullmann@kde.org>
-   Copyright (C) 2005 Dominik Haumann (dhdev@gmx.de) (documentation)
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+/*
+    SPDX-FileCopyrightText: 2001 Christoph Cullmann <cullmann@kde.org>
+
+    Documentation:
+    SPDX-FileCopyrightText: 2005 Dominik Haumann <dhdev@gmx.de>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #ifndef KTEXTEDITOR_VIEW_H
 #define KTEXTEDITOR_VIEW_H
 
 #include <ktexteditor_export.h>
-#include <ktexteditor/attribute.h>
-#include <ktexteditor/document.h>
-#include <ktexteditor/range.h>
 
 // gui merging
+#include <KSyntaxHighlighting/Theme>
 #include <KXMLGUIClient>
+#include <ktexteditor/codecompletionmodel.h>
 
 // widget
+#include <QSet>
 #include <QWidget>
 
 class QMenu;
-
+class QScrollBar;
 class KConfigGroup;
 
+namespace KSyntaxHighlighting
+{
+class Theme;
+}
+
 namespace KTextEditor
 {
-
 class Document;
 class MainWindow;
 class ViewPrivate;
+class Attribute;
+class AttributeBlock;
+class Range;
+class Cursor;
+class AnnotationModel;
+class AbstractAnnotationItemDelegate;
+class InlineNoteProvider;
+class TextHintProvider;
+class CodeCompletionModel;
 
 /**
+ * \class View view.h <KTextEditor/View>
+ *
  * \brief A text widget with KXMLGUIClient that represents a Document.
  *
  * Topics:
@@ -53,7 +57,11 @@ class ViewPrivate;
  *  - \ref view_cursors
  *  - \ref view_mouse_tracking
  *  - \ref view_modes
- *  - \ref view_extensions
+ *  - \ref view_config
+ *  - \ref view_annoview
+ *  - \ref view_inlinenote
+ *  - \ref view_texthint
+ *  - \ref view_compiface
  *
  * \section view_intro Introduction
  *
@@ -134,23 +142,104 @@ class ViewPrivate;
  * Whenever the input/view mode changes the signals
  * viewInputModeChanged()/viewModeChanged() are emitted.
  *
- * \section view_extensions View Extension Interfaces
+ * \section view_config View Config
+ * Config provides methods to access and modify the low level config information for a given
+ * View
+ * KTextEditor::View has support for the following keys:
+ *  - line-numbers [bool], show/hide line numbers
+ *  - icon-bar [bool], show/hide icon bar
+ *  - folding-bar [bool], show/hide the folding bar
+ *  - folding-preview [bool], enable/disable folding preview when mouse hovers
+ *    on folded region
+ *  - dynamic-word-wrap [bool], enable/disable dynamic word wrap
+ *  - background-color [QColor], read/set the default background color
+ *  - selection-color [QColor], read/set the default color for selections
+ *  - search-highlight-color [QColor], read/set the background color for search
+ *  - replace-highlight-color [QColor], read/set the background color for replaces
+ *  - default-mark-type [uint], read/set the default mark type
+ *  - allow-mark-menu [bool], enable/disable the menu shown when right clicking
+ *    on the left gutter. When disabled, click on the gutter will always set
+ *    or clear the mark of default type.
+ *  - icon-border-color [QColor] read/set the icon border color (on the left,
+ *    with the line numbers)
+ *  - folding-marker-color [QColor] read/set folding marker colors (in the icon border)
+ *  - line-number-color [QColor] read/set line number colors (in the icon border)
+ *  - current-line-number-color [QColor] read/set current line number color (in the icon border)
+ *  - modification-markers [bool] read/set whether the modification markers are shown
+ *  - word-count [bool] enable/disable the counting of words and characters in the statusbar
+ *  - line-count [bool] show/hide the total number of lines in the status bar (@since 5.66)
+ *  - scrollbar-minimap [bool] enable/disable scrollbar minimap
+ *  - scrollbar-preview [bool] enable/disable scrollbar text preview on hover
+ *  - font [QFont] change the font
+ *  - theme [QString] change the theme
+ *  - word-completion-minimal-word-length [int] minimal word length to trigger word completion
  *
- * A simple view represents the text of a Document and provides a text cursor,
- * text selection, edit modes etc.
- * Advanced concepts like code completion and text hints are defined in the
- * extension interfaces. An KTextEditor implementation does not need to
- * support all the extensions. To implement the interfaces multiple
- * inheritance is used.
+ * You can retrieve the value of a config key using configValue() and set the value
+ * for a config key using setConfigValue().
+ *
+ * \section view_annoview Annotation Interface
+ *
+ * The Annotation Interface allows to do these things:
+ * - (1) show/hide the annotation border along with the possibility to add actions
+ *       into its context menu.
+ * - (2) set a separate AnnotationModel for the View: Note that this interface
+ *       inherits the AnnotationInterface.
+ * - (3) set a custom AbstractAnnotationItemDelegate for the View.
+ *
+ * For a more detailed explanation about whether you want to set a custom
+ * delegate for rendering the annotations, read the detailed documentation about the
+ * AbstractAnnotationItemDelegate.
+ *
+ * \section view_inlinenote Inline Notes
+ *
+ * The inline notes interface provides a way to render arbitrary things in
+ * the text. The text layout of the line is adapted to create space for the
+ * note. Possible applications include showing a name of a function parameter
+ * in a function call or rendering a square with a color preview next to CSS
+ * color property.
+ *
+ * \image html inlinenote.png "Inline note showing a CSS color preview"
+ *
+ * To register as inline note provider, call registerInlineNoteProvider() with
+ * an instance that inherits InlineNoteProvider. Finally, make sure you remove
+ * your inline note provider by calling unregisterInlineNoteProvider().
+ *
+ * \section view_texthint Introduction
+ *
+ * The text hint interface provides a way to show tool tips for text located
+ * under the mouse. Possible applications include showing a value of a variable
+ * when debugging an application, or showing a complete path of an include
+ * directive.
+ *
+ * \image html texthint.png "Text hint showing the contents of a variable"
+ *
+ * To register as text hint provider, call registerTextHintProvider() with an
+ * instance that inherits TextHintProvider. Finally, make sure you remove your
+ * text hint provider by calling unregisterTextHintProvider().
+ *
+ * Text hints are shown after the user hovers with the mouse for a delay of
+ * textHintDelay() milliseconds over the same word. To change the delay, call
+ * setTextHintDelay().
+ *
+ * \section view_compiface Completion Interface
+ *
+ * The Completion Interface is designed to provide code completion
+ * functionality for a KTextEditor::View. This interface provides the basic
+ * mechanisms to display a list of completions, update this list according
+ * to user input, and allow the user to select a completion.
+ *
+ * Essentially, this provides an item view for the available completions. In
+ * order to use this interface, you will need to implement a
+ * CodeCompletionModel that generates the relevant completions given the
+ * current input.
  *
  * More information about interfaces for the view can be found in
  * \ref kte_group_view_extensions.
  *
- * \see KTextEditor::Document, KTextEditor::CodeCompletionInterface,
- *      KXMLGUIClient
+ * \see KTextEditor::Document, KXMLGUIClient
  * \author Christoph Cullmann \<cullmann@kde.org\>
  */
-class KTEXTEDITOR_EXPORT View :  public QWidget, public KXMLGUIClient
+class KTEXTEDITOR_EXPORT View : public QWidget, public KXMLGUIClient
 {
     Q_OBJECT
 
@@ -172,7 +261,7 @@ public:
     /**
      * Virtual destructor.
      */
-    virtual ~View();
+    ~View() override;
 
     /*
      * Accessor for the document
@@ -190,12 +279,12 @@ public:
      */
 public:
     /**
-    * Possible input modes.
-    * These correspond to various modes the text editor might be in.
-    */
+     * Possible input modes.
+     * These correspond to various modes the text editor might be in.
+     */
     enum InputMode {
         NormalInputMode = 0, /**< Normal Mode. */
-        ViInputMode = 1      /**< Vi mode. The view will behave like the editor vi(m) */
+        ViInputMode = 1 /**< Vi mode. The view will behave like the editor vi(m) */
     };
 
     /**
@@ -203,7 +292,7 @@ public:
      * These correspond to various modes the text editor might be in.
      */
     enum ViewMode {
-        NormalModeInsert = 0,    /**< Insert mode. Characters will be added. */
+        NormalModeInsert = 0, /**< Insert mode. Characters will be added. */
         NormalModeOverwrite = 1, /**< Overwrite mode. Characters will be replaced. */
 
         ViModeNormal = 10,
@@ -216,10 +305,11 @@ public:
 
     /**
      * Possible line types
+     * \since 5.33
      */
     enum LineType {
-        RealLine = 0,   /** < Real line. */
-        VisibleLine = 1 /** < Visible line. Line that is not folded. */
+        RealLine = 0, /**< Real line */
+        VisibleLine = 1 /**< Visible line. Line that is not folded. */
     };
     /**
      * Get the current view mode/state.
@@ -244,6 +334,14 @@ public:
      */
     virtual QString viewModeHuman() const = 0;
 
+    /**
+     * Set the view's new input mode.
+     * \param inputMode new InputMode value
+     * \see viewInputMode()
+     * @since 5.54
+     */
+    virtual void setViewInputMode(InputMode inputMode) = 0;
+
     /**
      * Get the view's current input mode.
      * The current mode can be \NormalInputMode and \ViInputMode.
@@ -311,9 +409,7 @@ Q_SIGNALS:
      * \param text the text the user has typed into the editor
      * \see insertText()
      */
-    void textInserted(KTextEditor::View *view,
-                      const KTextEditor::Cursor &position,
-                      const QString &text);
+    void textInserted(KTextEditor::View *view, KTextEditor::Cursor position, const QString &text);
 
     /*
      * Context menu handling
@@ -363,8 +459,8 @@ public:
      * }
      *
      * if (client->factory()) {
-     *   QList<QWidget*> conts = client->factory()->containers("menu");
-     *   foreach (QWidget *w, conts) {
+     *   const QList<QWidget*> menuContainers = client->factory()->containers("menu");
+     *   for (QWidget *w : menuContainers) {
      *     if (w->objectName() == "ktexteditor_popup") {
      *       // do something with the menu (ie adding an onshow handler)
      *       break;
@@ -392,21 +488,49 @@ Q_SIGNALS:
 public:
     /**
      * Set the view's new cursor to \p position. A \e TAB character
-     * is handeled as only on character.
+     * is handled as only on character.
      * \param position new cursor position
      * \return \e true on success, otherwise \e false
      * \see cursorPosition()
      */
     virtual bool setCursorPosition(Cursor position) = 0;
 
+    /**
+     * Set the view's new cursors to \p positions. A \e TAB character
+     * is handled as only on character.
+     *
+     * This allows to create multiple cursors in this view.
+     *
+     * The first passed position will be used for the primary cursor
+     * just like if you would call \ref setCursorPosition.
+     *
+     * \param positions new cursor positions
+     * \see cursorPositions()
+     *
+     * @since 5.95
+     */
+    void setCursorPositions(const QList<KTextEditor::Cursor> &positions);
+
     /**
      * Get the view's current cursor position. A \e TAB character is
-     * handeled as only one character.
+     * handled as only one character.
      * \return current cursor position
      * \see setCursorPosition()
      */
     virtual Cursor cursorPosition() const = 0;
 
+    /**
+     * Get the view's current cursor positions. A \e TAB character is
+     * handled as only one character.
+     *
+     * The returned vector contains the primary cursor as first element.
+     *
+     * @since 5.95
+     *
+     * \return all currently existing cursors
+     */
+    QList<KTextEditor::Cursor> cursorPositions() const;
+
     /**
      * Get the current \e virtual cursor position, \e virtual means the
      * tabulator character (TAB) counts \e multiple characters, as configured
@@ -432,7 +556,7 @@ public:
      *
      * \see cursorPositionCoordinates(), coordinatesToCursor()
      */
-    virtual QPoint cursorToCoordinate(const KTextEditor::Cursor &cursor) const = 0;
+    virtual QPoint cursorToCoordinate(KTextEditor::Cursor cursor) const = 0;
 
     /**
      * Get the screen coordinates (x, y) of the cursor position in pixels.
@@ -473,18 +597,17 @@ Q_SIGNALS:
      * This signal is emitted whenever the \p view's cursor position changed.
      * \param view view which emitted the signal
      * \param newPosition new position of the cursor (Kate will pass the real
-     *        cursor potition, not the virtual)
+     *        cursor position, not the virtual)
      * \see cursorPosition(), cursorPositionVirtual()
      */
-    void cursorPositionChanged(KTextEditor::View *view,
-                               const KTextEditor::Cursor &newPosition);
+    void cursorPositionChanged(KTextEditor::View *view, KTextEditor::Cursor newPosition);
 
     /**
      * This signal should be emitted whenever the \p view is scrolled vertically.
      * \param view view which emitted the signal
      * \param newPos the new scroll position
      */
-    void verticalScrollPositionChanged(KTextEditor::View *view, const KTextEditor::Cursor &newPos);
+    void verticalScrollPositionChanged(KTextEditor::View *view, KTextEditor::Cursor newPos);
 
     /**
      * This signal should be emitted whenever the \p view is scrolled horizontally.
@@ -534,11 +657,10 @@ Q_SIGNALS:
      *        mouse moved out of the \p view.
      * \see mouseTrackingEnabled()
      */
-    void mousePositionChanged(KTextEditor::View *view,
-                              const KTextEditor::Cursor &newPosition);
+    void mousePositionChanged(KTextEditor::View *view, KTextEditor::Cursor newPosition);
 
     /*
-     * Selection methodes.
+     * Selection methods.
      * This deals with text selection and copy&paste
      */
 public:
@@ -550,7 +672,17 @@ public:
      *         range is invalid)
      * \see selectionRange(), selection()
      */
-    virtual bool setSelection(const Range &range) = 0;
+    virtual bool setSelection(Range range) = 0;
+
+    /**
+     * Set the view's selection to the range \p selection.
+     * The old selection will be discarded.
+     * \param ranges the ranges of the new selections
+     * \see selectionRanges(), selection()
+     *
+     * @since 5.95
+     */
+    void setSelections(const QList<KTextEditor::Range> &ranges);
 
     /**
      * Query the view whether it has selected text, i.e. whether a selection
@@ -567,6 +699,15 @@ public:
      */
     virtual Range selectionRange() const = 0;
 
+    /**
+     * Get the ranges occupied by the current selections.
+     * \return selection ranges, valid only if a selection currently exists.
+     * \see setSelections()
+     *
+     * @since 5.95
+     */
+    QList<KTextEditor::Range> selectionRanges() const;
+
     /**
      * Get the view's selected text.
      * \return the selected text
@@ -655,22 +796,23 @@ public:
      * \param script script with functions which can be used in @p templateScript
      * \return true on success, false if insertion failed (e.g. read-only mode)
      */
-    bool insertTemplate(const KTextEditor::Cursor& insertPosition,
-                        const QString& templateString,
-                        const QString& script = QString());
-
+    bool insertTemplate(KTextEditor::Cursor insertPosition, const QString &templateString, const QString &script = QString());
 
     /**
-    * Scroll view to cursor.
-    *
-    * \param cursor the cursor position to scroll to.
-    */
-    void setScrollPosition(KTextEditor::Cursor &cursor);
+     * Scroll view to cursor.
+     *
+     * \param cursor the cursor position to scroll to.
+     *
+     * \since 5.33
+     */
+    void setScrollPosition(KTextEditor::Cursor cursor);
 
     /**
      * Horizontally scroll view to position.
      *
      * \param x the pixel position to scroll to.
+     *
+     * \since 5.33
      */
     void setHorizontalScrollPosition(int x);
 
@@ -679,38 +821,42 @@ public:
      * the view can vertically scroll to.
      *
      * \return cursor position of the maximum vertical scroll position.
+     *
+     * \since 5.33
      */
     KTextEditor::Cursor maxScrollPosition() const;
 
     /**
      * Get the first displayed line in the view.
      *
-     * \param real if REAL (the default), it returns the real line number
+     * \note If code is folded, many hundred lines can be
+     * between firstDisplayedLine() and lastDisplayedLine().
+     *
+     * \param lineType if RealLine (the default), it returns the real line number
      * accounting for folded regions. In that case it walks over all folded
      * regions
      * O(n) for n == number of folded ranges
+     * \return the first displayed line
      *
-     * \note if code is folded, many hundred lines can be
-     * between firstVisibleLine() and lastVisibleLine().
-     *
-     * \return the first visible line.
-     * \see lastVisibleLine()
+     * \see lastDisplayedLine()
+     * \since 5.33
      */
     int firstDisplayedLine(LineType lineType = RealLine) const;
 
     /**
      * Get the last displayed line in the view.
      *
-     * \param lineType if REAL (the default), it returns the real line number
+     * \note If code is folded, many hundred lines can be
+     * between firstDisplayedLine() and lastDisplayedLine().
+     *
+     * \param lineType if RealLine (the default), it returns the real line number
      * accounting for folded regions. In that case it walks over all folded
      * regions
      * O(n) for n == number of folded ranges
+     * \return the last displayed line
      *
-     * \note if code is folded, many hundred lines can be
-     * between firstVisibleLine() and lastVisibleLine().
-     *
-     * \return the last visible line.
-     * \see firstVisibleLine()
+     * \see firstDisplayedLine()
+     * \since 5.33
      */
     int lastDisplayedLine(LineType lineType = RealLine) const;
 
@@ -718,9 +864,23 @@ public:
      * Get the view's text area rectangle excluding border, scrollbars, etc.
      *
      * \return the view's text area rectangle
+     *
+     * \since 5.33
      */
     QRect textAreaRect() const;
 
+    /**
+     * \return The vertical scrollbar of this view
+     * \since 6.0
+     */
+    virtual QScrollBar *verticalScrollBar() const = 0;
+
+    /**
+     * \return The horizontal scrollbar of this view
+     * \since 6.0
+     */
+    virtual QScrollBar *horizontalScrollBar() const = 0;
+
 public:
     /**
      * Print the document. This should result in showing the print dialog.
@@ -786,7 +946,7 @@ public:
      * @param defaultStyle default style to get the attribute for
      * @see KTextEditor::Attribute
      */
-    virtual KTextEditor::Attribute::Ptr defaultStyleAttribute(KTextEditor::DefaultStyle defaultStyle) const = 0;
+    virtual QExplicitlySharedDataPointer<KTextEditor::Attribute> defaultStyleAttribute(KSyntaxHighlighting::Theme::TextStyle defaultStyle) const = 0;
 
     /**
      * Get the list of AttributeBlocks for a given \p line in the document.
@@ -795,6 +955,285 @@ public:
      */
     virtual QList<KTextEditor::AttributeBlock> lineAttributes(int line) = 0;
 
+Q_SIGNALS:
+    /**
+     * This signal is emitted whenever the current view configuration is changed.
+     *
+     * \param view the view which's config has changed
+     *
+     * \since 5.79
+     */
+    void configChanged(KTextEditor::View *view);
+
+    /**
+     * View Config
+     */
+public:
+    /**
+     * Get a list of all available keys.
+     */
+    virtual QStringList configKeys() const = 0;
+    /**
+     * Get a value for the \p key.
+     */
+    virtual QVariant configValue(const QString &key) = 0;
+    /**
+     * Set a the \p key's value to \p value.
+     */
+    virtual void setConfigValue(const QString &key, const QVariant &value) = 0;
+
+    /**
+     * View Annotation Interface
+     */
+public:
+    /**
+     * Sets a new \ref AnnotationModel for this document to provide
+     * annotation information for each line.
+     *
+     * \param model the new AnnotationModel
+     */
+    virtual void setAnnotationModel(AnnotationModel *model) = 0;
+
+    /**
+     * returns the currently set \ref AnnotationModel or 0 if there's none
+     * set
+     * @returns the current \ref AnnotationModel
+     */
+    virtual AnnotationModel *annotationModel() const = 0;
+
+    /**
+     * This function can be used to show or hide the annotation border
+     * The annotation border is hidden by default.
+     *
+     * @param visible if \e true the annotation border is shown, otherwise hidden
+     */
+    virtual void setAnnotationBorderVisible(bool visible) = 0;
+
+    /**
+     * Checks whether the View's annotation border is visible.
+     */
+    virtual bool isAnnotationBorderVisible() const = 0;
+
+    /**
+     * Sets the AbstractAnnotationItemDelegate for this view and the model
+     * to provide custom rendering of annotation information for each line.
+     * Ownership is not transferred.
+     *
+     * \param delegate the new AbstractAnnotationItemDelegate, or \c nullptr to reset to the default delegate
+     *
+     * @since 6.0
+     */
+    virtual void setAnnotationItemDelegate(KTextEditor::AbstractAnnotationItemDelegate *delegate) = 0;
+
+    /**
+     * Returns the currently used AbstractAnnotationItemDelegate
+     *
+     * @returns the current AbstractAnnotationItemDelegate
+     *
+     * @since 6.0
+     */
+    virtual KTextEditor::AbstractAnnotationItemDelegate *annotationItemDelegate() const = 0;
+
+    /**
+     * This function can be used to declare whether it is known that the annotation items
+     * rendered by the set delegate all have the same size.
+     * This enables the view to do some optimizations for performance purposes.
+     *
+     * By default the value of this property is \c false .
+     *
+     * @param uniformItemSizes if \c true the annotation items are considered to all have the same size
+     *
+     * @since 6.0
+     */
+    virtual void setAnnotationUniformItemSizes(bool uniformItemSizes) = 0;
+
+    /**
+     * Checks whether the annotation items all have the same size.
+     *
+     * @since 6.0
+     */
+    virtual bool uniformAnnotationItemSizes() const = 0;
+
+Q_SIGNALS:
+    /**
+     * This signal is emitted before a context menu is shown on the annotation
+     * border for the given line and view.
+     *
+     * \note Kate Part implementation detail: In Kate Part, the menu has an
+     *       entry to hide the annotation border.
+     *
+     * \param view the view that the annotation border belongs to
+     * \param menu the context menu that will be shown
+     * \param line the annotated line for which the context menu is shown
+     */
+    void annotationContextMenuAboutToShow(KTextEditor::View *view, QMenu *menu, int line);
+
+    /**
+     * This signal is emitted when an entry on the annotation border was activated,
+     * for example by clicking or double-clicking it. This follows the KDE wide
+     * setting for activation via click or double-clcik
+     *
+     * \param view the view to which the activated border belongs to
+     * \param line the document line that the activated position belongs to
+     */
+    void annotationActivated(KTextEditor::View *view, int line);
+
+    /**
+     * This signal is emitted when the annotation border is shown or hidden.
+     *
+     * \param view the view to which the border belongs to
+     * \param visible the current visibility state
+     */
+    void annotationBorderVisibilityChanged(KTextEditor::View *view, bool visible);
+
+    /**
+     * Inline Note
+     */
+public:
+    /**
+     * Register the inline note provider @p provider.
+     *
+     * Whenever a line is painted, the @p provider will be queried for notes
+     * that should be painted in it. When the provider is about to be
+     * destroyed, make sure to call unregisterInlineNoteProvider() to avoid a
+     * dangling pointer.
+     *
+     * @param provider inline note provider
+     * @see unregisterInlineNoteProvider(), InlineNoteProvider
+     */
+    virtual void registerInlineNoteProvider(KTextEditor::InlineNoteProvider *provider) = 0;
+
+    /**
+     * Unregister the inline note provider @p provider.
+     *
+     * @param provider inline note provider to unregister
+     * @see registerInlineNoteProvider(), InlineNoteProvider
+     */
+    virtual void unregisterInlineNoteProvider(KTextEditor::InlineNoteProvider *provider) = 0;
+
+    /**
+     * Text Hint
+     */
+public:
+    /**
+     * Register the text hint provider \p provider.
+     *
+     * Whenever the user hovers over text, \p provider will be asked for
+     * a text hint. When the provider is about to be destroyed, make
+     * sure to call unregisterTextHintProvider() to avoid a dangling pointer.
+     *
+     * @param provider text hint provider
+     * @see unregisterTextHintProvider(), TextHintProvider
+     */
+    virtual void registerTextHintProvider(KTextEditor::TextHintProvider *provider) = 0;
+
+    /**
+     * Unregister the text hint provider \p provider.
+     *
+     * @param provider text hint provider to unregister
+     * @see registerTextHintProvider(), TextHintProvider
+     */
+    virtual void unregisterTextHintProvider(KTextEditor::TextHintProvider *provider) = 0;
+
+    /**
+     * Set the text hint delay to \p delay milliseconds.
+     *
+     * The delay specifies the time the user needs to hover over the text
+     * before the tool tip is shown. Therefore, \p delay should not be
+     * too large, a value of 500 milliseconds is recommended and set by
+     * default.
+     *
+     * If \p delay is <= 0, the default delay will be set.
+     *
+     * \param delay tool tip delay in milliseconds
+     */
+    virtual void setTextHintDelay(int delay) = 0;
+
+    /**
+     * Get the text hint delay in milliseconds.
+     * By default, the text hint delay is set to 500 milliseconds.
+     * It can be changed by calling \p setTextHintDelay().
+     */
+    virtual int textHintDelay() const = 0;
+
+    /**
+     * Completion
+     */
+public:
+    /**
+     * Query whether the code completion box is currently displayed.
+     */
+    virtual bool isCompletionActive() const = 0;
+
+    /**
+     * Invoke code completion over a given range, with a specific \a model.
+     */
+    virtual void startCompletion(Range word, CodeCompletionModel *model) = 0;
+
+    /**
+     * Abort the currently displayed code completion without executing any currently
+     * selected completion. This is safe, even when the completion box is not currently
+     * active.
+     * \see isCompletionActive()
+     */
+    virtual void abortCompletion() = 0;
+
+    /**
+     * Force execution of the currently selected completion, and hide the code completion
+     * box.
+     */
+    virtual void forceCompletion() = 0;
+
+    /**
+     * Register a new code completion \p model.
+     * \param model new completion model
+     * \see unregisterCompletionModel()
+     */
+    virtual void registerCompletionModel(CodeCompletionModel *model) = 0;
+
+    /**
+     * Unregister a code completion \p model.
+     * \param model the model that should be unregistered
+     * \see registerCompletionModel()
+     */
+    virtual void unregisterCompletionModel(CodeCompletionModel *model) = 0;
+
+    /**
+     * Determine the status of automatic code completion invocation.
+     */
+    virtual bool isAutomaticInvocationEnabled() const = 0;
+
+    /**
+     * Enable or disable automatic code completion invocation.
+     */
+    virtual void setAutomaticInvocationEnabled(bool enabled = true) = 0;
+
+    /**
+     * Invoke code completion over a given range, with specific models and invocation type.
+     * \param models list of models to start. If this is an empty list, all registered models are started.
+     */
+    virtual void startCompletion(const Range &word,
+                                 const QList<CodeCompletionModel *> &models = QList<CodeCompletionModel *>(),
+                                 KTextEditor::CodeCompletionModel::InvocationType invocationType = KTextEditor::CodeCompletionModel::ManualInvocation) = 0;
+
+    /**
+     * Obtain the list of registered code completion models.
+     * \returns a list of a models that are currently registered
+     * \see registerCompletionModel(CodeCompletionModel*)
+     */
+    virtual QList<CodeCompletionModel *> codeCompletionModels() const = 0;
+
+public:
+    /**
+     * Get the current active theme of this view.
+     * Might change during runtime, configChanged() will be emitted in that cases.
+     *
+     * \return current active theme
+     *
+     * \since 5.79
+     */
+    KSyntaxHighlighting::Theme theme() const;
+
 private:
     /**
      * private d-pointer, pointing to the internal implementation
@@ -805,4 +1244,3 @@ private:
 }
 
 #endif
-
