@@ -11,6 +11,7 @@
 
 #include "kateundo.h"
 
+#include "katebuffer.h"
 #include "katedocument.h"
 #include "kateundomanager.h"
 #include "kateview.h"
@@ -40,11 +41,9 @@ void KateUndoGroup::undo(KateUndoManager *manager, KTextEditor::ViewPrivate *vie
     auto doc = manager->document();
     auto updateDocLine = [doc](const UndoItem &item) {
         Kate::TextLine tl = doc->plainKateTextLine(item.line);
-        Q_ASSERT(tl);
-        if (tl) {
-            tl->markAsModified(item.lineModFlags.testFlag(UndoItem::UndoLine1Modified));
-            tl->markAsSavedOnDisk(item.lineModFlags.testFlag(UndoItem::UndoLine1Saved));
-        }
+        tl.markAsModified(item.lineModFlags.testFlag(UndoItem::UndoLine1Modified));
+        tl.markAsSavedOnDisk(item.lineModFlags.testFlag(UndoItem::UndoLine1Saved));
+        doc->buffer().setLineMetaData(item.line, tl);
     };
 
     for (auto rit = m_items.rbegin(); rit != m_items.rend(); ++rit) {
@@ -67,8 +66,9 @@ void KateUndoGroup::undo(KateUndoManager *manager, KTextEditor::ViewPrivate *vie
             updateDocLine(item);
 
             auto next = doc->plainKateTextLine(item.line + 1);
-            next->markAsModified(item.lineModFlags.testFlag(UndoItem::UndoLine2Modified));
-            next->markAsSavedOnDisk(item.lineModFlags.testFlag(UndoItem::UndoLine2Saved));
+            next.markAsModified(item.lineModFlags.testFlag(UndoItem::UndoLine2Modified));
+            next.markAsSavedOnDisk(item.lineModFlags.testFlag(UndoItem::UndoLine2Saved));
+            doc->buffer().setLineMetaData(item.line + 1, next);
         } break;
         case UndoItem::editInsertLine:
             doc->editRemoveLine(item.line);
@@ -113,11 +113,9 @@ void KateUndoGroup::redo(KateUndoManager *manager, KTextEditor::ViewPrivate *vie
     auto doc = manager->document();
     auto updateDocLine = [doc](const UndoItem &item) {
         Kate::TextLine tl = doc->plainKateTextLine(item.line);
-        Q_ASSERT(tl);
-        if (tl) {
-            tl->markAsModified(item.lineModFlags.testFlag(UndoItem::RedoLine1Modified));
-            tl->markAsSavedOnDisk(item.lineModFlags.testFlag(UndoItem::RedoLine1Saved));
-        }
+        tl.markAsModified(item.lineModFlags.testFlag(UndoItem::RedoLine1Modified));
+        tl.markAsSavedOnDisk(item.lineModFlags.testFlag(UndoItem::RedoLine1Saved));
+        doc->buffer().setLineMetaData(item.line, tl);
     };
 
     for (auto &item : m_items) {
@@ -135,11 +133,9 @@ void KateUndoGroup::redo(KateUndoManager *manager, KTextEditor::ViewPrivate *vie
             updateDocLine(item);
 
             Kate::TextLine next = doc->plainKateTextLine(item.line + 1);
-            Q_ASSERT(next);
-            if (next) {
-                next->markAsModified(item.lineModFlags.testFlag(UndoItem::RedoLine2Modified));
-                next->markAsSavedOnDisk(item.lineModFlags.testFlag(UndoItem::RedoLine2Saved));
-            }
+            next.markAsModified(item.lineModFlags.testFlag(UndoItem::RedoLine2Modified));
+            next.markAsSavedOnDisk(item.lineModFlags.testFlag(UndoItem::RedoLine2Saved));
+            doc->buffer().setLineMetaData(item.line + 1, next);
         } break;
         case UndoItem::editUnWrapLine:
             doc->editUnWrapLine(item.line, item.removeLine, item.len);
@@ -188,11 +184,15 @@ void KateUndoGroup::editEnd(const KTextEditor::Cursor cursorPosition,
 
 static bool mergeUndoItems(UndoItem &base, const UndoItem &u)
 {
-    if (base.type != u.type) {
-        return false;
+    if (base.type == UndoItem::editInsertText && u.type == UndoItem::editWrapLine) {
+        if (base.line == u.line && base.col + base.text.length() == u.col && u.newLine) {
+            base.type = UndoItem::editInsertLine;
+            base.lineModFlags.setFlag(UndoItem::RedoLine1Modified);
+            return true;
+        }
     }
 
-    if (base.type == UndoItem::editRemoveText) {
+    if (base.type == UndoItem::editRemoveText && base.type == u.type) {
         if (base.line == u.line && base.col == (u.col + u.text.size())) {
             base.text.prepend(u.text);
             base.col = u.col;
@@ -200,7 +200,7 @@ static bool mergeUndoItems(UndoItem &base, const UndoItem &u)
         }
     }
 
-    if (base.type == UndoItem::editInsertText) {
+    if (base.type == UndoItem::editInsertText && base.type == u.type) {
         if (base.line == u.line && (base.col + base.text.size()) == u.col) {
             base.text += u.text;
             return true;
@@ -213,7 +213,7 @@ static bool mergeUndoItems(UndoItem &base, const UndoItem &u)
 void KateUndoGroup::addItem(UndoItem u)
 {
     // try to merge, do that only for equal types, inside mergeWith we do hard casts
-    if (!m_items.empty() && m_items.back().type == u.type && mergeUndoItems(m_items.back(), u)) {
+    if (!m_items.empty() && mergeUndoItems(m_items.back(), u)) {
         return;
     }
 
