@@ -42,14 +42,14 @@ CommandMode::CommandMode(EmulatedCommandBar *emulatedCommandBar,
     , m_interactiveSedReplaceMode(interactiveSedReplaceMode)
     , m_completer(completer)
 {
-    QVector<KTextEditor::Command *> cmds;
+    QList<KTextEditor::Command *> cmds;
     cmds.push_back(KateCommands::CoreCommands::self());
     cmds.push_back(Commands::self());
     cmds.push_back(AppCommands::self());
     cmds.push_back(SedReplace::self());
     cmds.push_back(BufferCommands::self());
 
-    for (KTextEditor::Command *cmd : KateScriptManager::self()->commandLineScripts()) {
+    for (KateCommandLineScript *cmd : KateScriptManager::self()->commandLineScripts()) {
         cmds.push_back(cmd);
     }
 
@@ -179,10 +179,9 @@ QString CommandMode::executeCommand(const QString &commandToExecute)
     if (cmd.length() > 0) {
         KTextEditor::Command *p = queryCommand(cmd);
         if (p) {
-            KateViCommandInterface *ci = dynamic_cast<KateViCommandInterface *>(p);
-            if (ci) {
-                ci->setViInputModeManager(viInputModeManager());
-                ci->setViGlobal(viInputModeManager()->globalState());
+            if (p == Commands::self() || p == SedReplace::self()) {
+                Commands::self()->setViInputModeManager(viInputModeManager());
+                SedReplace::self()->setViInputModeManager(viInputModeManager());
             }
 
             // The following commands changes the focus themselves, so bar should be hidden before execution.
@@ -215,7 +214,7 @@ QString CommandMode::executeCommand(const QString &commandToExecute)
     static const QRegularExpression reCmds(
         QStringLiteral("^(?:buffer|b|new|vnew|bp|bprev|tabp|tabprev|bn|bnext|tabn|tabnext|bf|bfirst|tabf|tabfirst"
                        "|bl|blast|tabl|tablast|e|edit|tabe|tabedit|tabnew)$"));
-    if (!reCmds.match(QStringView(cmd).left(cmd.indexOf(QLatin1Char(' ')))).hasMatch()) {
+    if (!reCmds.matchView(QStringView(cmd).left(cmd.indexOf(QLatin1Char(' ')))).hasMatch()) {
         view()->setFocus();
     }
 
